/*
 *   stunnel       Universal SSL tunnel
 *   Copyright (c) 1998-1999 Michal Trojnara <Michal.Trojnara@centertel.pl>
 *                 All Rights Reserved
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "stunnel.h"
#include "sthreads.h"
#include <unistd.h> /* for getpid() */

#ifdef USE_PTHREAD

#include <pthread.h>

pthread_mutex_t lock_cs[CRYPTO_NUM_LOCKS];

static void locking_callback(int mode, int type, char *file, int line)
{
    if(mode&CRYPTO_LOCK)
        pthread_mutex_lock(lock_cs+type);
    else
        pthread_mutex_unlock(lock_cs+type);
}

void sthreads_init()
{
    int i;

    for(i=0; i<CRYPTO_NUM_LOCKS; i++)
        pthread_mutex_init(lock_cs+i, NULL);
    CRYPTO_set_id_callback(thread_id);
    CRYPTO_set_locking_callback(locking_callback);
}

unsigned long process_id()
{
    return (unsigned long)getpid();
}

unsigned long thread_id()
{
    return (unsigned long)pthread_self();
}
#endif

#ifdef USE_WIN32

#include <windows.h>

void sthreads_init()
{
    /* empty */
}

unsigned long process_id()
{
    return GetCurrentProcessId();
}

unsigned long thread_id()
{
    return GetCurrentThreadId();
}
#endif

#ifdef USE_FORK
void sthreads_init()
{
    /* empty */
}

unsigned long process_id()
{
    return (unsigned long)getpid();
}

unsigned long thread_id()
{
    return 0L;
}
#endif

